@@ -19,15 +19,12 @@
 import abc
 import collections
 import contextlib
-import functools
-import itertools
 import json
 import logging
 import os
-import random
-import string
-from types import TracebackType
+import uuid
 from typing import Any
+from typing import AnyStr
 from typing import ClassVar
 from typing import ContextManager
 from typing import FrozenSet
@@ -37,20 +34,16 @@ from typing import List
 from typing import Mapping
 from typing import Optional
 from typing import Tuple
-from typing import Type
 from typing import Union
 from typing import cast
-from typing import overload
 
 from redis import Redis
 from redis import RedisError
 from redis.client import Pipeline
 from typing_extensions import Final
-from typing_extensions import Literal
 
 from . import monkey
 from .annotations import JSONTypes
-from .annotations import RedisValues
 from .exceptions import QuorumIsImpossible
 from .exceptions import RandomKeyError
 
@@ -63,7 +56,6 @@ _logger: Final[logging.Logger] = logging.getLogger('pottery')
 def random_key(*,
                redis: Redis,
                prefix: str = 'pottery:',
-               length: int = 16,
                num_tries: int = 3,
                ) -> str:
     'Find/return a random key that does not exist in the Redis instance.'
@@ -74,15 +66,12 @@ def random_key(*,
     if num_tries == 0:
         raise RandomKeyError(redis)
 
-    all_chars = string.digits + string.ascii_letters
-    random_char = functools.partial(random.choice, all_chars)
-    suffix = ''.join(cast(str, random_char()) for n in range(length))
-    key = prefix + suffix
+    uuid4 = str(uuid.uuid4())
+    key = prefix + uuid4
     if redis.exists(key):
         key = random_key(
             redis=redis,
             prefix=prefix,
-            length=length,
             num_tries=num_tries-1,
         )
     return key
@@ -150,39 +139,15 @@ class _Encodable:
         return encoded
 
     @staticmethod
-    def _decode(value: bytes) -> JSONTypes:
-        decoded: JSONTypes = json.loads(value.decode('utf-8'))
+    def _decode(value: AnyStr) -> JSONTypes:
+        try:
+            string = cast(bytes, value).decode('utf-8')
+        except AttributeError:
+            string = cast(str, value)
+        decoded: JSONTypes = json.loads(string)
         return decoded
 
 
-class _Comparable(metaclass=abc.ABCMeta):
-    'Mixin class that implements equality testing for Redis-backed collections.'
-
-    @property
-    @abc.abstractmethod
-    def redis(self) -> Redis:
-        'Redis client.'
-
-    @property
-    @abc.abstractmethod
-    def key(self) -> str:
-        'Redis key.'
-
-    def __eq__(self, other: Any) -> bool:
-        if self is other:
-            return True
-        if (
-            isinstance(other, _Comparable)
-            and self.redis.connection_pool == other.redis.connection_pool  # NoQA: W503
-            and self.key == other.key  # NoQA: W503
-        ):
-            return True
-        equals = super().__eq__(other)
-        if equals is NotImplemented:
-            equals = False
-        return equals
-
-
 class _Clearable(metaclass=abc.ABCMeta):
     'Mixin class that implements clearing (emptying) a Redis-backed collection.'
 
@@ -201,51 +166,6 @@ class _Clearable(metaclass=abc.ABCMeta):
         self.redis.delete(self.key)
 
 
-class _ContextPipeline:
-    '''Context manager that sets up, then executes, a Redis pipeline.
-
-    Redis pipelines: https://redis.io/topics/pipelining
-    Redis transactions: https://redis.io/topics/transactions
-    '''
-
-    __slots__ = ('redis', 'pipeline')
-
-    def __init__(self, redis: Redis) -> None:
-        self.redis = redis
-
-    def __enter__(self) -> Pipeline:
-        self.pipeline = self.redis.pipeline()
-        return self.pipeline
-
-    @overload
-    def __exit__(self,
-                 exc_type: None,
-                 exc_value: None,
-                 exc_traceback: None,
-                 ) -> Literal[False]:
-        raise NotImplementedError
-
-    @overload
-    def __exit__(self,
-                 exc_type: Type[BaseException],
-                 exc_value: BaseException,
-                 exc_traceback: TracebackType,
-                 ) -> Literal[False]:
-        raise NotImplementedError
-
-    def __exit__(self,
-                 exc_type: Optional[Type[BaseException]],
-                 exc_value: Optional[BaseException],
-                 exc_traceback: Optional[TracebackType],
-                 ) -> Literal[False]:
-        if exc_type is None:
-            with contextlib.suppress(RedisError):
-                self.pipeline.multi()
-                self.pipeline.ping()
-            self.pipeline.execute()
-        return False
-
-
 class _Pipelined(metaclass=abc.ABCMeta):
     @property
     @abc.abstractmethod
@@ -261,17 +181,33 @@ class _Pipelined(metaclass=abc.ABCMeta):
     def __watch_keys(self,
                      *keys: str,
                      ) -> Generator[Pipeline, None, None]:
-        with _ContextPipeline(self.redis) as pipeline:
+        with self.redis.pipeline() as pipeline:
             pipeline.watch(*keys)
-            yield pipeline
+            try:
+                yield pipeline
+            except Exception as error:
+                _logger.warning(
+                    'Caught %s; aborting pipeline of %d commands',
+                    error.__class__.__name__,
+                    len(pipeline),
+                )
+                raise
+            else:
+                _logger.info(
+                    'Running EXEC on pipeline of %d commands',
+                    len(pipeline),
+                )
+                pipeline.execute()
 
     def __context_managers(self,
                            *others: Any,
                            ) -> Generator[ContextManager[Pipeline], None, None]:
         redises = collections.defaultdict(list)
-        for container in itertools.chain((self,), others):
+        for container in (self, *others):
             if isinstance(container, _Pipelined):
-                connection_kwargs = frozenset(container.redis.connection_pool.connection_kwargs.items())
+                connection_kwargs = frozenset(
+                    container.redis.connection_pool.connection_kwargs.items(),
+                )
                 redises[connection_kwargs].append(container)
         for containers in redises.values():
             keys = (container.key for container in containers)
@@ -282,6 +218,7 @@ class _Pipelined(metaclass=abc.ABCMeta):
     def _watch(self,
                *others: Any,
                ) -> Generator[Pipeline, None, None]:
+        'Watch self and others, and yield a Redis pipeline.'
         pipelines = []
         with contextlib.ExitStack() as stack:
             for context_manager in self.__context_managers(*others):
@@ -290,7 +227,49 @@ class _Pipelined(metaclass=abc.ABCMeta):
             yield pipelines[0]
 
 
-class Base(_Common, _Encodable, _Comparable, _Clearable, _Pipelined):
+class _Comparable(metaclass=abc.ABCMeta):
+    'Mixin class that implements equality testing for Redis-backed collections.'
+
+    @property
+    @abc.abstractmethod
+    def redis(self) -> Redis:
+        'Redis client.'
+
+    @property
+    @abc.abstractmethod
+    def key(self) -> str:
+        'Redis key.'
+
+    @abc.abstractmethod
+    @contextlib.contextmanager
+    def _watch(self,
+               *others: Any,
+               ) -> Generator[Pipeline, None, None]:
+        'Watch self and others, and yield a Redis pipeline.'
+
+    def _same_redis(self, *others: Any) -> bool:
+        for other in others:
+            if not isinstance(other, _Comparable):
+                return False
+            if self.redis.connection_pool != other.redis.connection_pool:
+                return False
+        return True
+
+    def __eq__(self, other: Any) -> bool:
+        if self is other:
+            return True
+
+        if self._same_redis(other) and self.key == other.key:
+            return True
+
+        with self._watch(other):
+            equals = super().__eq__(other)
+        if equals is NotImplemented:
+            equals = False
+        return equals
+
+
+class Base(_Common, _Encodable, _Clearable, _Pipelined, _Comparable):
     'Base class for Redis-backed collections.'
 
 
