@@ -24,7 +24,7 @@ import logging
 from typing import Any
 from typing import Callable
 from typing import ClassVar
-from typing import FrozenSet
+from typing import Collection
 from typing import Hashable
 from typing import Iterable
 from typing import NamedTuple
@@ -64,7 +64,8 @@ class CacheInfo(NamedTuple):
 
 
 def _arg_hash(*args: Hashable, **kwargs: Hashable) -> int:
-    return hash((args, frozenset(kwargs.items())))
+    kwargs_items = frozenset(kwargs.items())
+    return hash((args, kwargs_items))
 
 
 F = TypeVar('F', bound=Callable[..., JSONTypes])
@@ -254,7 +255,7 @@ class CachedOrderedDict(collections.OrderedDict):
                 items.append(item)
         return super().__init__(items)
 
-    def misses(self) -> FrozenSet[JSONTypes]:
+    def misses(self) -> Collection[JSONTypes]:
         return frozenset(self._misses)
 
     @_set_expiration
