@@ -21,6 +21,7 @@ from typing import Iterable
 from typing import Optional
 from typing import Tuple
 from typing import Union
+from typing import cast
 
 from redis import Redis
 from redis.client import Pipeline
@@ -59,6 +60,8 @@ class RedisDeque(RedisList, collections.deque):  # type: ignore
             if self.maxlen:
                 iterable = tuple(iterable)[-self.maxlen:]
             else:
+                # self.maxlen == 0.  Populate the RedisDeque with an empty
+                # iterable.
                 iterable = tuple()
         super()._populate(pipeline, iterable)
 
@@ -75,11 +78,13 @@ class RedisDeque(RedisList, collections.deque):  # type: ignore
 
     def insert(self, index: int, value: JSONTypes) -> None:
         'Insert an element into the RedisDeque before the given index.  O(n)'
-        if self.maxlen is not None and len(self) >= self.maxlen:
-            raise IndexError(
-                f'{self.__class__.__name__} already at its maximum size'
-            )
-        return super()._insert(index, value)
+        with self._watch() as pipeline:
+            current_length = cast(int, pipeline.llen(self.key))
+            if self.maxlen is not None and current_length >= self.maxlen:
+                raise IndexError(
+                    f'{self.__class__.__name__} already at its maximum size'
+                )
+            super()._insert(index, value, pipeline=pipeline)
 
     def append(self, value: JSONTypes) -> None:
         'Add an element to the right side of the RedisDeque.  O(1)'
@@ -111,15 +116,16 @@ class RedisDeque(RedisList, collections.deque):  # type: ignore
                  right: bool = True,
                  ) -> None:
         with self._watch(values) as pipeline:
-            push_method = 'rpush' if right else 'lpush'
+            push_method_name = 'rpush' if right else 'lpush'
             encoded_values = [self._encode(value) for value in values]
-            len_ = len(self) + len(encoded_values)
+            len_ = cast(int, pipeline.llen(self.key)) + len(encoded_values)
             trim_indices: Union[Tuple[int, int], Tuple] = tuple()
             if self.maxlen is not None and len_ >= self.maxlen:
                 trim_indices = (len_-self.maxlen, len_) if right else (0, self.maxlen-1)
 
             pipeline.multi()
-            getattr(pipeline, push_method)(self.key, *encoded_values)
+            push_method = getattr(pipeline, push_method_name)
+            push_method(self.key, *encoded_values)
             if trim_indices:
                 pipeline.ltrim(self.key, *trim_indices)
 
@@ -148,13 +154,14 @@ class RedisDeque(RedisList, collections.deque):  # type: ignore
                 # Rotating an empty RedisDeque is a no-op.
                 return
 
-            push_method = 'lpush' if n > 0 else 'rpush'
-            values = self[-n:][::-1] if n > 0 else self[:-n]
-            encoded_values = (self._encode(element) for element in values)
+            push_method_name = 'lpush' if n > 0 else 'rpush'
+            decoded_values = self[-n:][::-1] if n > 0 else self[:-n]
+            encoded_values = (self._encode(value) for value in decoded_values)
             trim_indices = (0, len(self)-1) if n > 0 else (-n, len(self)-1-n)
 
             pipeline.multi()
-            getattr(pipeline, push_method)(self.key, *encoded_values)
+            push_method = getattr(pipeline, push_method_name)
+            push_method(self.key, *encoded_values)
             pipeline.ltrim(self.key, *trim_indices)
 
     # Methods required for Raj's sanity:
