@@ -2,7 +2,17 @@
 #   executor.py                                                               #
 #                                                                             #
 #   Copyright © 2015-2021, Rajiv Bakulesh Shah, original author.              #
-#   All rights reserved.                                                      #
+#                                                                             #
+#   Licensed under the Apache License, Version 2.0 (the "License");           #
+#   you may not use this file except in compliance with the License.          #
+#   You may obtain a copy of the License at:                                  #
+#       http://www.apache.org/licenses/LICENSE-2.0                            #
+#                                                                             #
+#   Unless required by applicable law or agreed to in writing, software       #
+#   distributed under the License is distributed on an "AS IS" BASIS,         #
+#   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.  #
+#   See the License for the specific language governing permissions and       #
+#   limitations under the License.                                            #
 # --------------------------------------------------------------------------- #
 
 
@@ -10,6 +20,7 @@ import concurrent.futures
 from types import TracebackType
 from typing import Optional
 from typing import Type
+from typing import overload
 
 from typing_extensions import Literal
 
@@ -40,6 +51,23 @@ class BailOutExecutor(concurrent.futures.ThreadPoolExecutor):
     This subclass overrides .__exit__() to not wait for pending futures to
     complete before returning control to the main thread, allowing bail out.
     '''
+
+    @overload
+    def __exit__(self,
+                 exc_type: None,
+                 exc_value: None,
+                 exc_traceback: None,
+                 ) -> Literal[False]:
+        raise NotImplementedError
+
+    @overload
+    def __exit__(self,
+                 exc_type: Type[BaseException],
+                 exc_value: BaseException,
+                 exc_traceback: TracebackType,
+                 ) -> Literal[False]:
+        raise NotImplementedError
+
     def __exit__(self,
                  exc_type: Optional[Type[BaseException]],
                  exc_value: Optional[BaseException],
