@@ -19,6 +19,8 @@
 import collections.abc
 import functools
 import itertools
+import uuid
+import warnings
 from typing import Any
 from typing import Callable
 from typing import Iterable
@@ -34,6 +36,7 @@ from redis.client import Pipeline
 from .annotations import F
 from .base import Base
 from .base import JSONTypes
+from .exceptions import InefficientAccessWarning
 from .exceptions import KeyExistsError
 
 
@@ -109,7 +112,9 @@ class RedisList(Base, collections.abc.MutableSequence):
                 pipeline.lrange(self.key, start, stop)
                 encoded = pipeline.execute()[0]
                 encoded = encoded[::index.step]
-                value: Union[List[JSONTypes], JSONTypes] = [self._decode(value) for value in encoded]
+                value: Union[List[JSONTypes], JSONTypes] = [
+                    self._decode(value) for value in encoded
+                ]
         else:
             index = self.__slice_to_indices(index).start
             encoded = self.redis.lindex(self.key, index)
@@ -121,8 +126,12 @@ class RedisList(Base, collections.abc.MutableSequence):
     @_raise_on_error
     def __setitem__(self, index: int, value: JSONTypes) -> None:  # type: ignore
         'l.__setitem__(index, value) <==> l[index] = value.  O(n)'
-        if isinstance(index, slice):
-            with self._watch() as pipeline:
+        with self._watch() as pipeline:
+            if isinstance(index, slice):
+                warnings.warn(
+                    cast(str, InefficientAccessWarning.__doc__),
+                    InefficientAccessWarning,
+                )
                 encoded_values = [self._encode(value) for value in value]
                 indices = self.__slice_to_indices(index)
                 pipeline.multi()
@@ -134,9 +143,16 @@ class RedisList(Base, collections.abc.MutableSequence):
                     num += 1
                 if num:
                     pipeline.lrem(self.key, num, 0)
-        else:
-            index = self.__slice_to_indices(index).start
-            self.redis.lset(self.key, index, self._encode(value))
+            else:
+                index = self.__slice_to_indices(index).start
+                len_ = cast(int, pipeline.llen(self.key))
+                if index not in {-1, 0, len_-1}:
+                    warnings.warn(
+                        cast(str, InefficientAccessWarning.__doc__),
+                        InefficientAccessWarning,
+                    )
+                pipeline.multi()
+                pipeline.lset(self.key, index, self._encode(value))
 
     @_raise_on_error
     def __delitem__(self, index: Union[slice, int]) -> None:  # type: ignore
@@ -144,51 +160,68 @@ class RedisList(Base, collections.abc.MutableSequence):
         with self._watch() as pipeline:
             self.__delete(pipeline, index)
 
+    # Preserve the Open-Closed Principle with name mangling.
+    #   https://youtu.be/miGolgp9xq8?t=2086
+    #   https://stackoverflow.com/a/38534939
     def __delete(self, pipeline: Pipeline, index: Union[slice, int]) -> None:
         # Python's list API requires us to delete an element by *index.*  Redis
         # supports only deleting an element by *value.*  So our workaround is
-        # to set l[index] to 0, then to delete the value 0.  More info:
+        # to set l[index] to a UUID4, then to delete the value UUID4.  More
+        # info:
         #   http://redis.io/commands/lrem
+        warnings.warn(
+            cast(str, InefficientAccessWarning.__doc__),
+            InefficientAccessWarning,
+        )
         indices, num = self.__slice_to_indices(index), 0
+        uuid4 = str(uuid.uuid4())
         pipeline.multi()
         for index in indices:
-            pipeline.lset(self.key, index, 0)
+            pipeline.lset(self.key, index, uuid4)
             num += 1
         if num:
-            pipeline.lrem(self.key, num, 0)
+            pipeline.lrem(self.key, num, uuid4)
 
     def __len__(self) -> int:
         'Return the number of items in the RedisList.  O(1)'
         return self.redis.llen(self.key)
 
     def insert(self, index: int, value: JSONTypes) -> None:
-        'Insert an element into the RedisList before the given index.  O(n)'
-        self.__insert(index, value)
+        'Insert an element into the RedisDeque before the given index.  O(n)'
+        with self._watch() as pipeline:
+            self.__insert(index, value, pipeline=pipeline)
 
-    def _insert(self, index: int, value: JSONTypes) -> None:
+    def _insert(self,
+                index: int,
+                value: JSONTypes,
+                *,
+                pipeline: Pipeline,
+                ) -> None:
         encoded_value = self._encode(value)
-        if index <= 0:
-            self.redis.lpush(self.key, encoded_value)
-        elif index < len(self):
+        current_length = cast(int, pipeline.llen(self.key))
+        if 0 < index < current_length:
             # Python's list API requires us to insert an element before the
             # given *index.*  Redis supports only inserting an element before a
             # given (pivot) *value.*  So our workaround is to set the pivot
-            # value to 0, then to insert the desired value before the value 0,
-            # then to set the value 0 back to the original pivot value.  More
-            # info:
+            # value to a UUID4, then to insert the desired value before the
+            # UUID4, then to set the value UUID4 back to the original pivot
+            # pivot value.  More info:
             #   http://redis.io/commands/linsert
-            with self._watch() as pipeline:
-                pivot = self._encode(self[index])
-                pipeline.multi()
-                pipeline.lset(self.key, index, 0)
-                pipeline.linsert(self.key, 'BEFORE', 0, encoded_value)
-                pipeline.lset(self.key, index+1, pivot)
+            warnings.warn(
+                cast(str, InefficientAccessWarning.__doc__),
+                InefficientAccessWarning,
+            )
+            uuid4 = str(uuid.uuid4())
+            pivot = cast(bytes, pipeline.lindex(self.key, index))
+            pipeline.multi()
+            pipeline.lset(self.key, index, uuid4)
+            pipeline.linsert(self.key, 'BEFORE', uuid4, encoded_value)
+            pipeline.lset(self.key, index+1, pivot)
         else:
-            self.redis.rpush(self.key, encoded_value)
+            pipeline.multi()
+            push_method = pipeline.lpush if index <= 0 else pipeline.rpush
+            push_method(self.key, encoded_value)
 
-    # Preserve the Open-Closed Principle with name mangling.
-    #   https://youtu.be/miGolgp9xq8?t=2086
-    #   https://stackoverflow.com/a/38534939
     __insert = _insert
 
     # Methods required for Raj's sanity:
@@ -200,28 +233,53 @@ class RedisList(Base, collections.abc.MutableSequence):
         self.redis.sort(self.key, desc=reverse, store=self.key)
 
     def __eq__(self, other: Any) -> bool:
-        if super().__eq__(other):
-            # self and other are both RedisLists on the same Redis instance and
+        if self is other:
+            return True
+
+        if self._same_redis(other) and self.key == other.key:
+            # self and other are both RedisLists on the same Redis database and
             # with the same key.  No need to compare element by element.
             return True
-        else:
-            try:
-                if len(self) != len(other):
-                    # self and other are different lengths.
+
+        with self._watch(other) as pipeline:
+            len_xs = cast(int, pipeline.llen(self.key))
+            if isinstance(other, RedisList):
+                len_ys = cast(int, pipeline.llen(other.key))
+            else:
+                try:
+                    len_ys = len(other)
+                except TypeError:
+                    # TypeError: other has no len()
                     return False
-                elif isinstance(other, collections.abc.MutableSequence):
-                    # self and other are the same length, and other is an
-                    # ordered collection too.  Compare self's and other's
-                    # elements, pair by pair.
-                    with self._watch(other):
-                        return all(x == y for x, y in zip(self, other))
-                else:
-                    # self and other are the same length, but other is an
-                    # unordered collection.
-                    return False
-            except TypeError:
+            if len_xs != len_ys:
+                # self and other are different lengths.
                 return False
 
+            if isinstance(other, collections.abc.MutableSequence):
+                # self and other are the same length, and other is a mutable
+                # sequence too.  Compare self's and other's elements, pair by
+                # pair.
+                encoded_xs = cast(
+                    List[bytes],
+                    pipeline.lrange(self.key, 0, -1),
+                )
+                decoded_xs = (self._decode(x) for x in encoded_xs)
+                if isinstance(other, RedisList):
+                    encoded_ys = cast(
+                        List[bytes],
+                        pipeline.lrange(other.key, 0, -1),
+                    )
+                    decoded_ys: collections.abc.Iterable[Any] = (  # pragma: no cover
+                        self._decode(y) for y in encoded_ys
+                    )
+                else:
+                    decoded_ys = other
+                return all(x == y for x, y in zip(decoded_xs, decoded_ys))
+
+        # self and other are the same length, but other is an unordered
+        # collection.
+        return False
+
     def __add__(self, other: List[JSONTypes]) -> 'RedisList':
         'Append the items in other to the RedisList.  O(n)'
         with self._watch(other):
@@ -230,10 +288,7 @@ class RedisList(Base, collections.abc.MutableSequence):
 
     def __repr__(self) -> str:
         'Return the string representation of the RedisList.  O(n)'
-        encoded = self.redis.lrange(self.key, 0, -1)
-        with self._watch():
-            values = [self._decode(value) for value in encoded]
-        return self.__class__.__name__ + str(values)
+        return self.__class__.__name__ + str(self.to_list())
 
     # Method overrides:
 
@@ -283,4 +338,6 @@ class RedisList(Base, collections.abc.MutableSequence):
 
     def to_list(self) -> List[JSONTypes]:
         'Convert the RedisList to a Python list.  O(n)'
-        return list(self)
+        encoded = self.redis.lrange(self.key, 0, -1)
+        values = [self._decode(value) for value in encoded]
+        return values
