@@ -34,7 +34,7 @@ _logger: Final[logging.Logger] = logging.getLogger('pottery')
 # connection pools to be equal if they're connected to the same host, port, and
 # database.
 
-from redis import ConnectionPool  # isort:skip
+from redis import ConnectionPool  # isort: skip
 
 def __eq__(self: ConnectionPool, other: Any) -> bool:
     try:
@@ -64,7 +64,7 @@ def _default(self: Any, obj: Any) -> Union[Dict[str, Any], List[Any], str]:
     return_value: Union[Dict[str, Any], List[Any], str] = func(obj)
     return return_value
 
-import json  # isort:skip
+import json  # isort: skip
 _default.default = json.JSONEncoder().default  # type: ignore
 json.JSONEncoder.default = _default  # type: ignore
 
@@ -73,24 +73,3 @@ _logger.info(
     'instance of any class that defines a .to_dict(), .to_list(), or .to_str() '
     'method'
 )
-
-
-# Monkey patch the Redis client to implement the LOLWUT command.
-#     1. LOLWUT command: https://redis.io/commands/lolwut
-#     2. PR upstream: https://github.com/andymccurdy/redis-py/pull/1448
-
-from redis import Redis  # isort: skip
-
-def lolwut(self: Redis, *version_numbers: int) -> bytes:
-    "Get the Redis version and a piece of generative computer art"
-    if version_numbers:
-        return self.execute_command('LOLWUT VERSION', *version_numbers)
-    else:
-        return self.execute_command('LOLWUT')
-
-Redis.lolwut = lolwut  # type: ignore
-
-_logger.info(
-    'Monkey patched redis.Redis.lolwut() to get the Redis version and a piece '
-    'of generative art'
-)
