@@ -84,7 +84,7 @@ class _Scripts:
             self.__class__._set_id_script = master.register_script('''
                 local curr = tonumber(redis.call('get', KEYS[1]))
                 local next = tonumber(ARGV[1])
-                if curr < next then
+                if curr == nil or curr < next then
                     redis.call('set', KEYS[1], next)
                     return next
                 else
@@ -113,19 +113,23 @@ class NextId(_Scripts, Primitive):
     Clean up Redis for the doctest:
 
         >>> from redis import Redis
-        >>> Redis(socket_timeout=1).delete('nextid:current') in {0, 1}
+        >>> redis = Redis(socket_timeout=1)
+        >>> redis.delete('nextid:tweet-ids') in {0, 1}
         True
 
     Usage:
 
-        >>> ids1 = NextId()
-        >>> ids2 = NextId()
-        >>> next(ids1)
+        >>> tweet_ids_1 = NextId(key='tweet-ids', masters={redis})
+        >>> tweet_ids_2 = NextId(key='tweet-ids', masters={redis})
+        >>> next(tweet_ids_1)
         1
-        >>> next(ids2)
+        >>> next(tweet_ids_2)
         2
-        >>> next(ids1)
+        >>> next(tweet_ids_1)
         3
+        >>> tweet_ids_1.reset()
+        >>> next(tweet_ids_1)
+        1
     '''
 
     __slots__ = ('num_tries',)
@@ -146,12 +150,6 @@ class NextId(_Scripts, Primitive):
             raise_on_redis_errors=raise_on_redis_errors,
         )
         self.num_tries = num_tries
-        self.__init_masters()
-
-    def __init_masters(self) -> None:
-        with concurrent.futures.ThreadPoolExecutor() as executor:
-            for master in self.masters:
-                executor.submit(master.setnx, self.key, 0)
 
     def __iter__(self) -> 'NextId':
         return self
@@ -169,7 +167,7 @@ class NextId(_Scripts, Primitive):
 
     @property
     def __current_id(self) -> int:
-        with concurrent.futures.ThreadPoolExecutor() as executor:
+        with BailOutExecutor() as executor:
             futures = set()
             for master in self.masters:
                 future = executor.submit(master.get, self.key)
@@ -178,7 +176,7 @@ class NextId(_Scripts, Primitive):
             current_ids, redis_errors = [], []
             for future in concurrent.futures.as_completed(futures):
                 try:
-                    current_id = int(cast(bytes, future.result()))
+                    current_id = int(cast(bytes, future.result() or b'0'))
                 except RedisError as error:
                     redis_errors.append(error)
                     _logger.exception(
@@ -188,9 +186,9 @@ class NextId(_Scripts, Primitive):
                     )
                 else:
                     current_ids.append(current_id)
+                    if len(current_ids) > len(self.masters) // 2:  # pragma: no cover
+                        return max(current_ids)
 
-        if len(current_ids) > len(self.masters) // 2:
-            return max(current_ids)
         self._check_enough_masters_up(None, redis_errors)
         raise QuorumNotAchieved(
             self.key,
@@ -233,6 +231,37 @@ class NextId(_Scripts, Primitive):
             redis_errors=redis_errors,
         )
 
+    def reset(self) -> None:
+        'Reset the ID counter to 0.'
+        with concurrent.futures.ThreadPoolExecutor() as executor:
+            futures = set()
+            for master in self.masters:
+                future = executor.submit(master.delete, self.key)
+                futures.add(future)
+
+            num_masters_reset, redis_errors = 0, []
+            for future in concurrent.futures.as_completed(futures):
+                try:
+                    future.result()
+                except RedisError as error:
+                    redis_errors.append(error)
+                    _logger.exception(
+                        '%s.reset() caught %s',
+                        self.__class__.__name__,
+                        error.__class__.__name__,
+                    )
+                else:
+                    num_masters_reset += 1
+                    if num_masters_reset == len(self.masters):  # pragma: no cover
+                        return
+
+        self._check_enough_masters_up(None, redis_errors)
+        raise QuorumNotAchieved(
+            self.key,
+            self.masters,
+            redis_errors=redis_errors,
+        )
+
     def __repr__(self) -> str:
         return f'<{self.__class__.__name__} key={self.key}>'
 
@@ -243,5 +272,5 @@ if __name__ == '__main__':
     #   $ python3 -m pottery.nextid
     #   $ deactivate
     with contextlib.suppress(ImportError):
-        from tests.base import run_doctests  # type: ignore
+        from tests.base import run_doctests
         run_doctests()
